@@ -9,6 +9,7 @@ endpoint_suffix = '.volcengineapi.com'
 dualstack_endpoint_suffix = '.volcengine-api.com'
 fallback_endpoint = open_prefix + endpoint_suffix
 region_code_cn_beijing_auto_driving = "cn-beijing-autodriving"
+region_code_cn_shanghai_auto_driving = "cn-shanghai-autodriving"
 region_code_ap_southeast2 = "ap-southeast-2"
 region_code_ap_southeast3 = "ap-southeast-3"
 
@@ -422,6 +423,7 @@ bootstrap_region = {
     region_code_cn_beijing_auto_driving: {},
     region_code_ap_southeast2: {},
     region_code_ap_southeast3: {},
+    region_code_cn_shanghai_auto_driving: {},
 }
 
 
